==> igniteui-react-charts-16.6.8.tgz: package/ES2015/ColumnSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { ConsolidatedItemsPosition_$type } from "./ConsolidatedItemsPosition";
import { Type, runOn, enumGetBox, markType, fromEnum } from "igniteui-react-core/ES2015/type";
import { Pool$1 } from "igniteui-react-core/ES2015/Pool$1";
import { Rectangle } from "igniteui-react-core/ES2015/Rectangle";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { isNaN_, isInfinity } from "igniteui-react-core/ES2015/number";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
/**
 * @hidden
 */
export class ColumnSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.qg = null;
        this.qb = 0;
        this.ab = ColumnSeries.$;
        this.pu = 2;
    }
    bf() {
        return new ColumnSeriesView(this);
    }
    im(a) {
        super.im(a);
        this.qa = a;
    }
    m9() {
        return 1;
    }
    get_no() {
        return true;
    }
    preferredCategoryMode(a) {
        return this.pu;
    }
    ln(a) {
        if (this.qg == null) {
            this.qg = runOn(this, this.qd);
        }
        let b = this.px != null ? this.px : this.yAxis;
        let c = this.pr;
        return this.ow.c$d(this, a, c, b, this.m0, this.n0(this.bi), this.n1(this.bi), this.qg);
    }
    dg(a, b) {
        if (this.dj(a, b)) {
            return true;
        }
        if (this.lx(a, b)) {
            return true;
        }
        return false;
    }
    hp(a, b) {
        super.hp(a, b);
        let c = b;
        if (a && c.c7 != null) {
            c.c7.count = 0;
        }
    }
    ed() {
        return this.pr.jk(this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi));
    }
    oh(a, b) {
        super.oh(a, b);
        let c = a.f;
        if (!b.q()) {
            return;
        }
        let d = b.bs;
        let e = b.br;
        let f = this.getEffectiveViewport1(b);
        let g = new ScalerParams(0, d, e, this.px.b8, f);
        g.b = this.ee();
        let h = new ScalerParams(0, d, e, this.pr.b8, f);
        let i = this.px;
        let j = i.dt(i.j7, g);
        let k = this.pr.jk(d, e, f);
        let l = this.pr;
        let m = b;
        if (isNaN_(k) || isInfinity(k)) {
            m.c7.count = 0;
            return;
        }
        this.m7.x(this, this.ns(), this.pr, runOn(this, this.mt), this.n0(b), this.n1(b));
        this.m7.p = this.qe;
        this.m7.q = this.qf;
        this.m7.j = this.qe;
        this.m7.k = this.qf;
        let n = false;
        let o = this.m7.c;
        if (o != null) {
            n = true;
        }
        let p = this.pr.cc;
        let q = p ? this.pr : null;
        let r = this.valueColumn.count;
        let s = this.n0(b);
        let t = 0;
        for (let u = 0; u < c.count; ++u) {
            let v = c._inner[u][0] - 0.5 * k;
            let w = this.qd(c._inner[u]);
            let x = j;
            w = Math.max(w, -100);
            x = Math.min(x, e.bottom + 100);
            let y = Math.abs(x - w);
            if (isInfinity(y)) {
                continue;
            }
            let z = m.c7.item(t);
            t++;
            z.width = k;
            z.height = y;
            if (n) {
                this.od(c, u, r, l, h, b.n);
            }
            if (z.dataContext != null) {
                let aa = z.dataContext;
                if (s == 1) {
                    let ab = this.m7.a(r, u)[0];
                    if (ab >= 0 && ab < this.bz.count) {
                        if (q != null && q.i$b != null && q.i$b.count > ab) {
                            ab = q.i$b._inner[ab];
                        }
                        aa.item = this.bz.item(ab);
                    }
                }
                else {
                    aa.item = null;
                }
            }
            this.m7.ae(z, false, false, false, false);
            z.al = this.m7.j;
            z.am = this.m7.k;
            m.dc(z, v, Math.min(x, w));
        }
        m.c7.count = t;
        b.cu(a);
    }
    get qc() {
        return this.qb;
    }
    set qc(a) {
        if (this.qc != a) {
            let b = this.qc;
            this.qb = a;
            this.raisePropertyChanged("ConsolidatedColumnVerticalPosition", enumGetBox(ConsolidatedItemsPosition_$type, b), enumGetBox(ConsolidatedItemsPosition_$type, this.qc));
        }
    }
    qd(a) {
        if (a == null || a.length < 3) {
            return NaN;
        }
        switch (this.qc) {
            case 0: return a[1];
            case 1: return a[2];
            case 2: return (a[1] + a[2]) / 2;
            case 3:
                let b = (a[1] + a[2]) / 2;
                if (this.yAxis == null) {
                    return b;
                }
                let c = this.yAxis.dw(b, new ScalerParams(1, this.bs.m4, this.bs.m3, this.yAxis.b8));
                if (c < this.yAxis.j7) {
                    return a[2];
                }
                else {
                    return a[1];
                }
            case 4:
                let d = (a[1] + a[2]) / 2;
                let e = this.yAxis.dw(d, new ScalerParams(1, this.bs.m4, this.bs.m3, this.yAxis.b8));
                if (this.yAxis == null) {
                    return d;
                }
                if (e < this.yAxis.j7) {
                    return a[1];
                }
                else {
                    return a[2];
                }
            default: return (a[1] + a[2]) / 2;
        }
    }
    get useHighMarkerFidelity() {
        return this.nv;
    }
}
ColumnSeries.$t = markType(ColumnSeries, 'ColumnSeries', HorizontalAnchoredCategorySeries.$);
Type.dep(DependencyProperty, PropertyMetadata, ColumnSeries, 'raisePropertyChanged', ['RadiusX:qe:qk', [1, 2], 'RadiusY:qf:ql', [1, 2]]);
/**
 * @hidden
 */
export class ColumnSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c6 = null;
        this.c8 = null;
        this.dd = new Rectangle();
        this.c7 = null;
        this.c6 = a;
        this.c7 = ((() => {
            let $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(this, this.de);
            $ret.activate = runOn(this, this.c9);
            $ret.disactivate = runOn(this, this.db);
            $ret.destroy = runOn(this, this.da);
            return $ret;
        })());
    }
    ap() {
        super.ap();
        this.c8 = new List$1(Rectangle.$, 0);
        if (!this.n) {
            this.e.er = 4;
            this.e.bj = 1;
        }
    }
    de() {
        let a = new Rectangle();
        this.c8.add(a);
        a._visibility = 1;
        return a;
    }
    c9(a) {
        a._visibility = 0;
    }
    db(a) {
        a._visibility = 1;
    }
    da(a) {
        this.c8.remove(a);
    }
    dc(a, b, c) {
        if (!this.isDirty) {
            this.an();
        }
        a.o = c;
        a.n = b;
    }
    z(a) {
        return this.c8._inner[a];
    }
    y(a) {
        let b = this.c8._inner[a];
        this.dd._visibility = b._visibility;
        this.dd.n = b.n;
        this.dd.o = b.o;
        this.dd.width = b.width;
        this.dd.height = b.height;
        let c = this.bm(a);
        this.dd._fill = c;
        this.dd._stroke = c;
        this.dd.ac = this.e.ev + 3;
        return this.dd;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            for (let c = 0; c < this.c8.count; c++) {
                let d = this.x(c, b);
                this.ba(d, c, b);
                a.v(d);
            }
        }
    }
    ai(a) {
        super.ai(a);
        let b = 0;
        let c = new List$1(Rectangle.$, 0);
        for (let d of fromEnum(this.c7.a)) {
            c.add(d);
        }
        c.aa((e, f) => {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        for (let e of fromEnum(c)) {
            this.e.a2.exportRectangleData(a, e, "column" + b, ["Main", "Fill"]);
        }
        b++;
    }
}
ColumnSeriesView.$t = markType(ColumnSeriesView, 'ColumnSeriesView', AnchoredCategorySeriesView.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/ColumnSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { ConsolidatedItemsPosition_$type } from "./ConsolidatedItemsPosition";
import { Type, runOn, enumGetBox, markType, fromEnum } from "igniteui-react-core/ES2015/type";
import { Pool$1 } from "igniteui-react-core/ES2015/Pool$1";
import { Rectangle } from "igniteui-react-core/ES2015/Rectangle";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { isNaN_, isInfinity } from "igniteui-react-core/ES2015/number";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
/**
 * @hidden
 */
export class ColumnSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.qn = null;
        this.qi = 0;
        this.ab = ColumnSeries.$;
        this.p1 = 2;
    }
    bf() {
        return new ColumnSeriesView(this);
    }
    iu(a) {
        super.iu(a);
        this.qh = a;
    }
    ng() {
        return 1;
    }
    get_nv() {
        return true;
    }
    preferredCategoryMode(a) {
        return this.p1;
    }
    lu(a) {
        if (this.qn == null) {
            this.qn = runOn(this, this.qk);
        }
        let b = this.p4 != null ? this.p4 : this.yAxis;
        let c = this.py;
        return this.o3.c$d(this, a, c, b, this.m7, this.n7(this.bi), this.n8(this.bi), this.qn);
    }
    dh(a, b) {
        if (this.dk(a, b)) {
            return true;
        }
        if (this.l4(a, b)) {
            return true;
        }
        return false;
    }
    hv(a, b) {
        super.hv(a, b);
        let c = b;
        if (a && c.c7 != null) {
            c.c7.count = 0;
        }
    }
    eg() {
        return this.py.jr(this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi));
    }
    oo(a, b) {
        super.oo(a, b);
        let c = a.f;
        if (!b.q()) {
            return;
        }
        let d = b.bs;
        let e = b.br;
        let f = this.getEffectiveViewport1(b);
        let g = new ScalerParams(0, d, e, this.p4.b8, f);
        g.b = this.eh();
        let h = new ScalerParams(0, d, e, this.py.b8, f);
        let i = this.p4;
        let j = i.dw(i.ke, g);
        let k = this.py.jr(d, e, f);
        let l = this.py;
        let m = b;
        if (isNaN_(k) || isInfinity(k)) {
            m.c7.count = 0;
            return;
        }
        this.ne.x(this, this.nz(), this.py, runOn(this, this.m0), this.n7(b), this.n8(b));
        this.ne.p = this.ql;
        this.ne.q = this.qm;
        this.ne.j = this.ql;
        this.ne.k = this.qm;
        let n = false;
        let o = this.ne.c;
        if (o != null) {
            n = true;
        }
        let p = this.py.cd;
        let q = p ? this.py : null;
        let r = this.valueColumn.count;
        let s = this.n7(b);
        let t = 0;
        for (let u = 0; u < c.count; ++u) {
            let v = c._inner[u][0] - 0.5 * k;
            let w = this.qk(c._inner[u]);
            let x = j;
            w = Math.max(w, -100);
            x = Math.min(x, e.bottom + 100);
            let y = Math.abs(x - w);
            if (isInfinity(y)) {
                continue;
            }
            let z = m.c7.item(t);
            t++;
            z.width = k;
            z.height = y;
            if (n) {
                this.ok(c, u, r, l, h, b.n);
            }
            if (z.dataContext != null) {
                let aa = z.dataContext;
                if (s == 1) {
                    let ab = this.ne.a(r, u)[0];
                    if (ab >= 0 && ab < this.bz.count) {
                        if (q != null && q.i$b != null && q.i$b.count > ab) {
                            ab = q.i$b._inner[ab];
                        }
                        aa.item = this.bz.item(ab);
                    }
                }
                else {
                    aa.item = null;
                }
            }
            this.ne.ae(z, false, false, false, false);
            z.am = this.ne.j;
            z.an = this.ne.k;
            m.dc(z, v, Math.min(x, w));
        }
        m.c7.count = t;
        b.cu(a);
    }
    get qj() {
        return this.qi;
    }
    set qj(a) {
        if (this.qj != a) {
            let b = this.qj;
            this.qi = a;
            this.raisePropertyChanged("ConsolidatedColumnVerticalPosition", enumGetBox(ConsolidatedItemsPosition_$type, b), enumGetBox(ConsolidatedItemsPosition_$type, this.qj));
        }
    }
    qk(a) {
        if (a == null || a.length < 3) {
            return NaN;
        }
        switch (this.qj) {
            case 0: return a[1];
            case 1: return a[2];
            case 2: return (a[1] + a[2]) / 2;
            case 3:
                let b = (a[1] + a[2]) / 2;
                if (this.yAxis == null) {
                    return b;
                }
                let c = this.yAxis.dz(b, new ScalerParams(1, this.bs.m4, this.bs.m3, this.yAxis.b8));
                if (c < this.yAxis.ke) {
                    return a[2];
                }
                else {
                    return a[1];
                }
            case 4:
                let d = (a[1] + a[2]) / 2;
                let e = this.yAxis.dz(d, new ScalerParams(1, this.bs.m4, this.bs.m3, this.yAxis.b8));
                if (this.yAxis == null) {
                    return d;
                }
                if (e < this.yAxis.ke) {
                    return a[1];
                }
                else {
                    return a[2];
                }
            default: return (a[1] + a[2]) / 2;
        }
    }
    get useHighMarkerFidelity() {
        return this.n2;
    }
}
ColumnSeries.$t = markType(ColumnSeries, 'ColumnSeries', HorizontalAnchoredCategorySeries.$);
Type.dep(DependencyProperty, PropertyMetadata, ColumnSeries, 'raisePropertyChanged', ['RadiusX:ql:qr', [1, 2], 'RadiusY:qm:qs', [1, 2]]);
/**
 * @hidden
 */
export class ColumnSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c6 = null;
        this.c8 = null;
        this.dd = new Rectangle();
        this.c7 = null;
        this.c6 = a;
        this.c7 = ((() => {
            let $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(this, this.de);
            $ret.activate = runOn(this, this.c9);
            $ret.disactivate = runOn(this, this.db);
            $ret.destroy = runOn(this, this.da);
            return $ret;
        })());
    }
    ap() {
        super.ap();
        this.c8 = new List$1(Rectangle.$, 0);
        if (!this.n) {
            this.e.eu = 4;
            this.e.bj = 1;
        }
    }
    de() {
        let a = new Rectangle();
        this.c8.add(a);
        a._visibility = 1;
        return a;
    }
    c9(a) {
        a._visibility = 0;
    }
    db(a) {
        a._visibility = 1;
    }
    da(a) {
        this.c8.remove(a);
    }
    dc(a, b, c) {
        if (!this.isDirty) {
            this.an();
        }
        a.o = c;
        a.n = b;
    }
    z(a) {
        return this.c8._inner[a];
    }
    y(a) {
        let b = this.c8._inner[a];
        this.dd._visibility = b._visibility;
        this.dd.n = b.n;
        this.dd.o = b.o;
        this.dd.width = b.width;
        this.dd.height = b.height;
        let c = this.bm(a);
        this.dd._fill = c;
        this.dd._stroke = c;
        this.dd.ac = this.e.ey + 3;
        return this.dd;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            for (let c = 0; c < this.c8.count; c++) {
                let d = this.x(c, b);
                this.ba(d, c, b);
                a.v(d);
            }
        }
    }
    ai(a) {
        super.ai(a);
        let b = 0;
        let c = new List$1(Rectangle.$, 0);
        for (let d of fromEnum(this.c7.a)) {
            c.add(d);
        }
        c.aa((e, f) => {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        for (let e of fromEnum(c)) {
            this.e.a2.exportRectangleData(a, e, "column" + b, ["Main", "Fill"]);
        }
        b++;
    }
}
ColumnSeriesView.$t = markType(ColumnSeriesView, 'ColumnSeriesView', AnchoredCategorySeriesView.$);
